==> claromentis-framework-9.6.6-26891208.zip: web/intranet/infocapture/classes/Event/ChangeSlaWorkHoursEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
class ChangeSlaWorkHoursEvent extends Event implements ProjectEventInterface
{
    
    
    
    
    private $project;
    
    
    
    
    private $old_worktime;
    
    
    
    
    private $new_worktime;
    
    
    
    
    private $old_hp_group;
    
    
    
    
    private $new_hp_group;
    public function __construct(\HDProject $project, array $_69efc5ca728f9f0af4798e5ebd2ba78e, array $_7b59cbdfdb443ae682857e3bad5b2efd, int $_5205fc23bdc6957f7ff7e858bf26c5ee, int $_c08e0c831f054ed7ae4aea0af08d879f)
    {
        $this->project = $project;
        $this->old_worktime = $_69efc5ca728f9f0af4798e5ebd2ba78e;
        $this->new_worktime = $_7b59cbdfdb443ae682857e3bad5b2efd;
        $this->old_hp_group = $_5205fc23bdc6957f7ff7e858bf26c5ee;
        $this->new_hp_group = $_c08e0c831f054ed7ae4aea0af08d879f;
    }
    
    
    
    
    public function getProject() : \HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getOldWorktime() : array
    {
        return $this->old_worktime;
    }
    
    
    
    
    public function getNewWorktime() : array
    {
        return $this->new_worktime;
    }
    
    
    
    
    public function getOldHpGroup() : int
    {
        return $this->old_hp_group;
    }
    
    
    
    
    public function getNewHpGroup() : int
    {
        return $this->new_hp_group;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/infocapture/classes/Event/ChangeSlaWorkHoursEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] ?: array()) + array();
use Claromentis\Core\Event\Event;
class ChangeSlaWorkHoursEvent extends Event implements ProjectEventInterface
{
    
    
    
    
    private $project;
    
    
    
    
    private $old_worktime;
    
    
    
    
    private $new_worktime;
    
    
    
    
    private $old_hp_group;
    
    
    
    
    private $new_hp_group;
    public function __construct(\HDProject $project, array $_69efc5ca728f9f0af4798e5ebd2ba78e, array $_7b59cbdfdb443ae682857e3bad5b2efd, int $_5205fc23bdc6957f7ff7e858bf26c5ee, int $_c08e0c831f054ed7ae4aea0af08d879f)
    {
        $this->project = $project;
        $this->old_worktime = $_69efc5ca728f9f0af4798e5ebd2ba78e;
        $this->new_worktime = $_7b59cbdfdb443ae682857e3bad5b2efd;
        $this->old_hp_group = $_5205fc23bdc6957f7ff7e858bf26c5ee;
        $this->new_hp_group = $_c08e0c831f054ed7ae4aea0af08d879f;
    }
    
    
    
    
    public function getProject() : \HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getOldWorktime() : array
    {
        return $this->old_worktime;
    }
    
    
    
    
    public function getNewWorktime() : array
    {
        return $this->new_worktime;
    }
    
    
    
    
    public function getOldHpGroup() : int
    {
        return $this->old_hp_group;
    }
    
    
    
    
    public function getNewHpGroup() : int
    {
        return $this->new_hp_group;
    }
}
